/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
* Copyright (C) 2012 - 2014 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/
/*******************************************************************************
* File Name    : main.c
* $Rev: 1254 $
* $Date:: 2014-09-04 15:29:06 +0900#$
* Device(s)    : RZ/A1H
* Tool-Chain   : DS-5 Ver 5.16
*              : ARM Complier
* OS           : None
* H/W Platform : R7S72100 CPU Board
* Description  : RZ/A1H Sample Program - Main
* Operation    : 
* Limitations  : 
*******************************************************************************/


/******************************************************************************
Includes   <System Includes> , "Project Includes"
******************************************************************************/
#include <stdio.h>
#include "r_typedefs.h"
#include "dev_drv.h"            /* Device Driver common header */
#include "devdrv_ostm.h"        /* OSTM Driver Header */
#include "devdrv_rtc.h"         /* RTC Driver Header */
#include "main.h"
#include "sample_main.h"
#include "led.h"
#include "deep_standby_cancel.h"

/******************************************************************************
Typedef definitions
******************************************************************************/


/******************************************************************************
Macro definitions
******************************************************************************/
#define MAIN_LED_ON     (1)
#define MAIN_LED_OFF    (0)

/******************************************************************************
Imported global variables and functions (from other files)
******************************************************************************/


/******************************************************************************
Exported global variables and functions (to be accessed by other files)
******************************************************************************/


/******************************************************************************
Private global variables and functions
******************************************************************************/
/* ==== Prototype declaration ==== */
#if defined(__ICCARM__) || defined(__GNUC__)
void SystemInit(void);
#endif
static void     RTC_DispTimeCanDeepStb(void);
static uint16_t RTC_ConvFromBcd(uint16_t bcd);

/* ==== Global variables ==== */
static uint32_t main_led_flg;      /* LED lighting/turning off */


/******************************************************************************
* Function Name: main
* Description  : Displays the sample code information on the terminal of the host 
*              : PC which is connected to the GENMAI board by the serial interface. 
*              : If this function is called after the deep standby mode is cancelled, 
*              : displays the time when the deep standby mode is cancelled.
*              : Also, executes initial setting for the PORT connected with the 
*              : LEDs on the board. 
*              : Executes initial setting for the OSTM channel 0, and sets the 
*              : timer counter so that the OSTM0 interrupt occurs every 500ms.
* Arguments    : none
* Return Value : 0
******************************************************************************/
int_t main(void)
{
#if defined(__ICCARM__) || defined(__GNUC__)
    SystemInit();
#endif

    /* ==== Setup the I/O without buffering ==== */
#ifdef __ICCARM__
    setvbuf( stdout, NULL, _IONBF, 0 );
    setvbuf( stdin,  NULL, _IONBF, 0 );
#endif

#ifdef __CC_ARM
    printf("\nRZ/A1H CPU Board Sample Program. ");
#endif
#ifdef __ICCARM__
    printf("\nRZ/A1H CPU Board Sample Program for ICCARM. ");
#endif
#ifdef __GNUC__
    printf("\nRZ/A1H CPU Board Sample Program for KPIT GCC. ");
#endif
    printf("Ver.0.81\n");

    printf("Copyright (C) 2014 Renesas Electronics Corporation. All rights reserved.\n");
    printf("\n");

    /* ==== Display the time when deep standby mode is cancelled ==== */
    RTC_DispTimeCanDeepStb();

    /* ==== LED initial setting ==== */
    LedInit();                      /* PORTfunction setting       */
    main_led_flg = MAIN_LED_OFF;    /* Initialize LED on/off flag */

    /* ==== Initialize OS timer (channel 0) ==== */
    R_OSTM_Init(DEVDRV_CH_0, OSTM_MODE_INTERVAL, 500);

    /* ==== Start OS timer (channel 0) ==== */
    R_OSTM_Open(DEVDRV_CH_0);

    /* ==== Receive command, activate sample software ==== */
    Sample_Main();

    return 0;
}

/******************************************************************************
* Function Name: Sample_OSTM0_Interrupt
* Description  : This function is executed when the OSTM0 interrupt is received. 
*              : In this sample code, the processing to blink the LEDs on the 
*              : CPU board every 500ms is executed.
* Arguments    : uint32_t int_sense : Interrupt detection
*              :                    :   INTC_LEVEL_SENSITIVE : Level sense
*              :                    :   INTC_EDGE_TRIGGER    : Edge trigger
* Return Value : none
******************************************************************************/
void Sample_OSTM0_Interrupt(uint32_t int_sense)
{
    /* ==== LED blink ==== */
    main_led_flg ^= 1;

    if (MAIN_LED_ON == main_led_flg)
    {
        LedOn();
    }
    else
    {
        LedOff();
    }
}

/******************************************************************************
* Function Name: RTC_DispTimeCanDeepStb
* Description  : This is a sample function to obtain the time when the deep standby 
*              : mode is cancelled. 
*              : In the sample code, the value of the RTC time counter is obtained 
*              : by using the sample function RTC_GetTimeCanDeepStb. If the time 
*              : when the deep standby mode is cancelled is stored, the value 
*              : of the BCD-coded time counter is converted into integer value 
*              : and display to the terminal. 
* Arguments    : none
* Return Value : none
******************************************************************************/
static void RTC_DispTimeCanDeepStb(void)
{
    const char_t display_month[12][5] = 
      { "Jan.", "Feb.", "Mar.", "Apr.", "May.", "Jun.", "Jul.", "Aug.", "Sep.", "Oct.", "Nov.", "Dec." };
    const char_t display_week[RTC_WK_TOTAL][5] = 
      { "Sun.", "Mon.", "Tue.", "Wed.", "Thu.", "Fri.", "Sat." };
    rtc_time_t   time;
    rtc_time_t   can_time;
    uint32_t     state;

    /* ==== Obtain the time when deep standby mode is cancelled ==== */
    state = RTC_GetTimeCanDeepStb(&can_time);

    /* ==== If the time when deep standby mode is cancelled is stored   ==== */
    /* ==== (State of return from deep standby mode by alarm interrupt) ==== */
    if (STB_GENERATE_ALARM_INT == state)
    {
        time.second.value = (uint8_t)(RTC_ConvFromBcd((uint16_t)can_time.second.value));
        time.minute.value = (uint8_t)(RTC_ConvFromBcd((uint16_t)can_time.minute.value));
        time.hour.value   = (uint8_t)(RTC_ConvFromBcd((uint16_t)can_time.hour.value));
        time.week.value   = (uint8_t)(RTC_ConvFromBcd((uint16_t)can_time.week.value));
        time.day.value    = (uint8_t)(RTC_ConvFromBcd((uint16_t)can_time.day.value));
        time.month.value  = (uint8_t)(RTC_ConvFromBcd((uint16_t)can_time.month.value));
        time.year.value   = RTC_ConvFromBcd(can_time.year.value);

        /* ---- Display the time when deep standby mode is cancelled to terminal ---- */
        printf("Deep standby mode canceled at..\n");
        printf("------------------------------\n");
        printf("%4s %4s %2d, %4d at %02d:%02d:%02d\n", 
                display_week[time.week.value], 
                display_month[time.month.value - 1], 
                time.day.value, 
                time.year.value, 
                time.hour.value, 
                time.minute.value, 
                time.second.value);
        printf("------------------------------\n");
        printf("\n");
    }
}

/******************************************************************************
* Function Name: RTC_ConvFromBcd
* Description  : Converts the BCD-coded value specified by the argument bcd into 
*              : integer value and returns.
* Arguments    : uint16_t bcd : Value (BCD)
* Return Value : uint16_t : Integer value
******************************************************************************/
static uint16_t RTC_ConvFromBcd(uint16_t bcd)
{
    uint16_t value;

    value = 0;

    /* ==== Convert BCD-coded value into integer value ==== */
    value += (bcd / 0x1000) * 1000;
    value += ((bcd / 0x100) % 0x10) * 100;
    value += ((bcd / 0x10) % 0x10) * 10;
    value += bcd % 0x10;

    return value;
}


/* End of File */

