/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
* Copyright (C) 2012 - 2014 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/
/*******************************************************************************
* File Name   : sample_rtc_cmdlist.c
* $Rev: 1131 $
* $Date:: 2014-08-07 15:23:35 +0900#$
* Description : Realtime Clock(RTC) sample program - Command list
*******************************************************************************/


/******************************************************************************
Includes   <System Includes> , "Project Includes"
******************************************************************************/
#include <stdio.h>
#include "r_typedefs.h"
#include "command.h"
#include "sample_rtc.h"

/******************************************************************************
Typedef definitions
******************************************************************************/


/******************************************************************************
Macro definitions
******************************************************************************/


/******************************************************************************
Imported global variables and functions (from other files)
******************************************************************************/


/******************************************************************************
Exported global variables and functions (to be accessed by other files)
******************************************************************************/


/******************************************************************************
Private global variables and functions
******************************************************************************/
static const command_list_t sample_rtc_cmd_list[] = 
{
    {"1",       Sample_RTC_Init,                NULL},  /* 1: RTC initialize      */
    {"2",       Sample_RTC_SetTime,             NULL},  /* 2: Time set sample     */
    {"3",       Sample_RTC_GetTime,             NULL},  /* 3: Time get sample     */
    {"4",       Sample_RTC_Start,               NULL},  /* 4: RTC start sample    */
    {"5",       Sample_RTC_Stop,                NULL},  /* 5: RTC stop sample     */
    {"6",       Sample_RTC_DeepStandby,         NULL},  /* 6: Deep standby sample */
    {"HELP",    Sample_RTC_Help,                NULL},  /* Display command help   */
    {"EXIT",    Sample_RTC_Exit,                NULL},  /* Exit RTC sample        */
    {NULL,      NULL,                           NULL}
};

/******************************************************************************
* Function Name: Sample_RTC_Help
* Description  : Outputs command descriptions to the terminal.
* Arguments    : int32_t   argc : The number of command arguments input from 
*              :                : the terminal
*              : char_t ** argv : Pointer to the command input from the terminal
* Return Value : COMMAND_SUCCESS : Success
*              : COMMAND_ERROR   : Error
******************************************************************************/
int32_t Sample_RTC_Help(int32_t argc, char_t ** argv)
{
    /* ==== Command help ==== */
    if (1 == argc)
    {
        printf("\n");
        printf("  1    : Initialize RTC\n");
        printf("  2    : Set time\n");
        printf("  3    : Get time\n");
        printf("  4    : Start RTC\n");
        printf("  5    : Stop RTC\n");
        printf("  6    : Transition to deep standby mode\n");
        printf("       :  -> Canceled by RTC alarm interrupt\n");
        printf("  EXIT : Exit RTC sample\n");
        printf("\n");
    }
    else
    {
        printf("error: Command failure.\n");
        printf("\n");
        return COMMAND_ERROR;
    }

    return COMMAND_SUCCESS;
}

/******************************************************************************
* Function Name: Sample_RTC_GetCmdList
* Description  : Obtains the command list.
* Arguments    : none
* Return Value : command_list_t * : Start address of the command list
******************************************************************************/
const command_list_t * Sample_RTC_GetCmdList(void)
{
    return sample_rtc_cmd_list;
}

/* End of File */

